@@ -1,7 +1,7 @@
 package Text::ANSITable;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.49'; # VERSION
+our $DATE = '2018-05-31'; # DATE
+our $VERSION = '0.500'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -11,6 +11,7 @@ use experimental 'smartmatch';
 
 #use List::Util qw(first);
 use Scalar::Util 'looks_like_number';
+require Win32::Console::ANSI if $^O =~ /Win/;
 
 my $ATTRS = [qw(
 
@@ -697,7 +698,7 @@ sub list_style_sets {
     if ($detail) {
         return $all_sets;
     } else {
-        return sort keys %$all_sets;
+        return (sort keys %$all_sets);
     }
 }
 
@@ -1288,7 +1289,7 @@ sub draw_color_reset {
 # characters to print. n defaults to 1 if not specified.
 sub draw_border_char {
     my $self = shift;
-    my $args = shift if ref($_[0]) eq 'HASH';
+    my $args; $args = shift if ref($_[0]) eq 'HASH';
 
     $self->draw_str($self->{_draw}{set_line_draw_mode});
     while (my ($y, $x, $n) = splice @_, 0, 3) {
@@ -1671,7 +1672,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.49 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2017-07-10.
+This document describes version 0.500 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2018-05-31.
 
 =head1 SYNOPSIS
 
@@ -2930,7 +2931,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
